@@ -6,7 +6,7 @@ from typing import List
 from apyscript.display.display_object import DisplayObject
 from apyscript.expression import expression_file_util
 from apyscript.html import html_util
-from apyscript.type.int import Int
+from apyscript.type import Int
 from apyscript.validation import display_validation
 
 
