@@ -17,7 +17,8 @@ from apyscript.display.width_interface import WidthInterface
 from apyscript.expression import expression_file_util
 from apyscript.expression import expression_variables_util
 from apyscript.html import html_const
-from apyscript.type.number import Number
+from apyscript.type import Int
+from apyscript.type import Number
 from apyscript.validation import size_validation
 
 
@@ -27,12 +28,16 @@ class Rectangle(
         LineAlphaInterface):
 
     def __init__(
-            self, parent: Any, x: int, y: int, width: int,
-            height: int, fill_color: Optional[str] = None,
-            fill_alpha: Optional[Union[float, Number]] = None,
+            self, parent: Any,
+            x: Union[int, Int],
+            y: Union[int, Int],
+            width: Union[int, Int],
+            height: Union[int, Int],
+            fill_color: Optional[str] = None,
+            fill_alpha: Union[float, Number] = 1.0,
             line_color: Optional[str] = None,
-            line_thickness: Optional[int] = None,
-            line_alpha: Optional[float] = None) -> None:
+            line_thickness: Union[int, Int] = 1,
+            line_alpha: Union[float, Number] = 1.0) -> None:
         """
         Create a rectangle vector graphic.
 
@@ -40,44 +45,45 @@ class Rectangle(
         ----------
         parent : Graphics
             Graphics instance to link this graphic.
-        x : int
+        x : int or Int
             X position to start drawing.
-        y : int
+        y : int or Int
             Y position to start drawing.
-        width : int
+        width : int or Int
             Rectangle width.
-        height : int
+        height : int or Int
             Rectangle height.
         fill_color : str or None, default None
             Fill color (hexadecimal string, e.g., '#00aaff').
-        fill_alpha : float or Number or None, default None
+        fill_alpha : float or Number, default 1.0
             Fill opacity (0.0 to 1.0).
         line_color : str or None, default None
             Line color (hexadecimal string, e.g., '#00aaff').
-        line_thickness : str or None, default None
+        line_thickness : int or Int, default 1
             Line thickness (width).
-        line_alpha : float or None, default None
+        line_alpha : float or Number, default 1.0
             Line opacity (0.0 to 1.0).
         """
         variable_name: str = expression_variables_util.\
             get_next_variable_name(type_name='rectangle')
         super(Rectangle, self).__init__(
-            parent=parent, x=x, y=y, variable_name=variable_name)
+            parent=parent,
+            x=Int(x),
+            y=Int(y),
+            variable_name=variable_name)
         size_validation.validate_size_is_gte_zero(size=width)
         size_validation.validate_size_is_gte_zero(size=height)
-        self.update_width_and_skip_appending_exp(value=width)
-        self.update_height_and_skip_appending_exp(value=height)
+        self.update_width_and_skip_appending_exp(value=Int(width))
+        self.update_height_and_skip_appending_exp(value=Int(height))
         if fill_color is not None:
             self.update_fill_color_and_skip_appending_exp(value=fill_color)
-        if fill_alpha is not None:
-            self.update_fill_alpha_and_skip_appending_exp(value=fill_alpha)
+        self.update_fill_alpha_and_skip_appending_exp(value=fill_alpha)
         if line_color is not None:
             self.update_line_color_and_skip_appending_exp(value=line_color)
-        if line_thickness is not None:
-            self.update_line_thickness_and_skip_appending_exp(
-                value=line_thickness)
-        if line_alpha is not None:
-            self.update_line_alpha_and_skip_appending_exp(value=line_alpha)
+        self.update_line_thickness_and_skip_appending_exp(
+            value=Int(line_thickness))
+        self.update_line_alpha_and_skip_appending_exp(
+            value=Number(line_alpha))
 
 
 def append_draw_rect_expression(rectangle: Rectangle) -> None:
